#!/usr/bin/perl

  ### Include the standard library and define local variables.
  require '../guardiandigital-lib.pl';
  &ReadParse();

  if (!$in{'fcn'}) {
    ### Tell us where the magic files are.
    $INTERFACES = "/etc/network/interfaces";		## 01
    $HOSTNAME   = "/etc/hostname";			## 02
    $HOSTS      = "/etc/hosts";				## 03
    $RESOLV     = "/etc/resolv.conf";			## 04

    $POSTFIX_RESOLV = "/var/spool/postfix/etc/resolv.conf";
    $POSTFIX_HOSTS  = "/var/spool/postfix/etc/hosts";

    ### Decode input variables.
    $net_hostname = $in{'net_hostname'};
    $net_domainname = $in{'net_domainname'};
    $net_ip = $in{'net_ip'};
    $net_netmask = $in{'net_netmask'};
    $net_gateway = $in{'net_gateway'};
    $net_dns1 = $in{'net_dns1'};
    $net_dns2 = $in{'net_dns2'};

    ### Make sure the data was input to begin with.
    if (!$net_hostname) { &PrintError("Please enter a hostname."); exit; }
    if (!$net_domainname) { &PrintError("Please enter a domain name."); exit; }
    if (!$net_ip) { &PrintError("Please enter a IP address."); exit; }
    if (!$net_netmask) { &PrintError("Please enter a netmask."); exit; }
    if (!$net_gateway) { &PrintError("Please enter a default gateway."); exit; }
    if (!$net_dns1) { &PrintError("Please enter a DNS server."); exit; }

    ### Make sure hostname is [A-Za-z0-9\-]+ (in regexp speak)
    if ($net_hostname =~ m/[^A-Za-z0-9\-]/) {
      &PrintError("Hostname invalid.  Please use alphanumerics and '-'.");
      exit;
    }

    ### Make sure domain is [A-Za-z0-9\-\.]+
    elsif ($net_domainname =~ m/[^A-Za-z0-9\-\.]/) {
      &PrintError("Domain invalid.  Please use alphanumerics, '-', and '.'");
      exit;
    }

    ### Make sure IP address is formatted correctly.
    if (!&check_ipaddress($net_ip)) {
       &PrintError("Invalid IP address.  Please re-enter.");
    }

    ### Make sure netmask is formatted correctly.
    if (!&check_ipaddress($net_netmask)) {
       &PrintError("Invalid netmask address.  Please re-enter.");
    }

    ### Make sure gateway is formatted correctly.
    if (!&check_ipaddress($net_gateway)) {
       &PrintError("Invalid gateway address.  Please re-enter.");
    }

    ### Make sure dns is formatted correctly.
    if (!&check_ipaddress($net_dns1)) {
       &PrintError("Invalid primary DNS address.  Please re-enter.");
    }

    ### Make sure dns is formatted correctly.
    if (($net_dns2) && (!&check_ipaddress($net_dns2))) {
       &PrintError("Invalid secondary DNS address.  Please re-enter.");
    }



    ### ######################################################
    ### We have good input data, so now let's write our files.
    ###   1) Build the strings.
    ###   2) Write them to the appropriate file.
    ### ######################################################

    ### Run ipcalc to get the braodcast and network numbers.
    $IPCALC = `/bin/ipcalc --broadcast --network $net_ip $net_netmask`;

    ### Pull out the numbers we want and put in appropriate variables.
    ($net_broadcast) = ($IPCALC =~ m/BROADCAST\=(.*)/);
    ($net_network)   = ($IPCALC =~ m/NETWORK\=(.*)/);


    ### INTERFACES: /etc/network/interfaces
    $interfaces  = "# /etc/network/interfaces -- configuration file for ";
    $interfaces .= "ifup(8), ifdown(8)\n\n";

    $interfaces .= "# The loopback interface\n";
    $interfaces .= "iface lo inet loopback\n";
    $interfaces .= "  up route add -net 127.0.0.0 netmask 255.0.0.0 dev lo\n\n";

    $interfaces .= "# The first network card - this entry was created during ";
    $interfaces .= "the initial\n# configuration (network, broadcast and ";
    $interfaces .= "gateway are optional)\n";
    $interfaces .= "iface eth0 inet static\n";
    $interfaces .= "   address $net_ip\n";
    $interfaces .= "   netmask $net_netmask\n";
    $interfaces .= "   network $net_network\n";
    $interfaces .= "   broadcast $net_broadcast\n";
    $interfaces .= "   up route add default gw $net_gateway\n\n";

    ### HOSTNAME: /etc/hostname
    $hostname = "$net_hostname\.$net_domainname\n";

    ### HOSTS:  /etc/hosts
    $hosts  = "127.0.0.1\tlocalhost localhost\n";
    $hosts .= "$net_ip\t$net_hostname\.$net_domainname $net_hostname\n";

    ### RESOLV:  /etc/resolv.conf
    $resolv  = "search $net_domainname\n";
    $resolv .= "nameserver $net_dns1\n";
    if ($net_dns2) { $resolv .= "nameserver $net_dns2\n"; }






    ### Write INTERFACES.
    &obtain_lock($INTERFACES);
    open INTERFACES, ">$INTERFACES";
      print INTERFACES $interfaces;
    close INTERFACES;
    &release_lock($INTERFACES);

    ### Write HOSTNAME.
    &obtain_lock($HOSTNAME);
    open HOSTNAME, ">$HOSTNAME";
      print HOSTNAME $hostname;
    close HOSTNAME;
    &release_lock($HOSTNAME);

    ### Write HOSTS.
    &obtain_lock($HOSTS);
    open HOSTS, ">$HOSTS";
      print HOSTS $hosts;
    close HOSTS;
    &release_lock($HOSTS);

    ### Write RESOLV.
    &obtain_lock($RESOLV);
    open RESOLV, ">$RESOLV";
      print RESOLV $resolv;
    close RESOLV;
    &release_lock($RESOLV);

    ### Put a copy of /etc/resolv.conf and /etc/hosts in the Postfix jail.
    system "cp $RESOLV $POSTFIX_RESOLV";
    system "cp $HOSTS $POSTFIX_HOSTS";
    system "chown postfix.postfix $POSTFIX_RESOLV $POSTFIX_HOSTS";
  }

  ### Take them to their "Happy Place (tm)".
  &redirect("step5.cgi");
  exit;

